@@ -24,6 +24,7 @@ use futures::{future::BoxFuture, Stream};
 use condow_client::CondowClient;
 use config::{AlwaysGetSize, Config};
 use errors::CondowError;
+use multi::MultiRangeDownloader;
 use reporter::{NoReporting, Reporter, ReporterFactory};
 use streams::{ChunkStream, ChunkStreamItem, PartStream};
 
@@ -36,6 +37,7 @@ mod download_session;
 mod downloader;
 pub mod errors;
 mod machinery;
+pub mod multi;
 pub mod reporter;
 pub mod streams;
 
@@ -141,6 +143,11 @@ impl<C: CondowClient> Condow<C> {
         DownloadSession::new_with_reporting_arc(self.clone(), rep_fac)
     }
 
+    /// Create a new [MultiRangeDownloader] without reporting
+    pub fn multi_range_downloader(&self) -> MultiRangeDownloader<C> {
+        MultiRangeDownloader::new_with_reporting_arc(self.clone(), Arc::new(NoReporting))
+    }
+
     /// Download a BLOB range (potentially) concurrently
     ///
     /// Returns a stream of [Chunk](streams::Chunk)s.
