@@ -4,7 +4,7 @@ use std::{
 };
 
 use bytes::Bytes;
-use futures::{ready, Stream, StreamExt};
+use futures::{ready, AsyncRead, Stream, StreamExt};
 use pin_project_lite::pin_project;
 
 use crate::errors::CondowError;
@@ -257,6 +257,16 @@ impl<St: Stream<Item = ChunkStreamItem>> Stream for PartStream<St> {
     }
 }
 
+impl<St: Stream<Item = ChunkStreamItem>> AsyncRead for PartStream<St> {
+    fn poll_read(
+        self: std::pin::Pin<&mut Self>,
+        cx: &mut Context<'_>,
+        buf: &mut [u8],
+    ) -> Poll<std::io::Result<usize>> {
+        todo!()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use futures::StreamExt;
